function [Q, cH_max] = h2hlewis(gvars)
% h2hlewis solves the open economy model for a symmetric configuration
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Trade Reforms and Labor Market Adjustments - Codes - v 2011/11/20
% Head-to-head with Lewis-like unemployment extending Helpman-Itskhoki
%
% h2hlewis(tau, check,gvars) computes the eqm variables
% and returns the equilibrium outcomes
% w = wages, P = price index, R = income = revenues,
% piH = H-sector profits, lH = H-sector wage bill,
% tM = tightness in M sector, tH = tightness in H sector
%
% ASSUMPTIONS
% assuming L0 == L1 == L & N0 == N1 == N
% assuming LM0 == LM1 == LM
% assuming LH0 == LH1 == LH
%
% CONVENTION
% In this code,
% the country code i,j is in 0,1
% so (1-j) is the other country relative to j
%
% CONVENTION
% The unit costs cji or c_comp embed the iceberg cost already.
%
% CHANGES:
% >>> 2011/09/18 no fixed costs + Pareto distributions + Symmetry
% >>> 2011/09/20 added more input arguments (myeps)
% >>> 2011/09/19 corrected the double-counting of the tau(j,i)
% >>> 2011/09/20 added more output arguments (aggprofitsH & agglaborH)
% >>> 2011/09/20 added more input arguments (check)
% >>> 2011/09/22 add tau and H as local arguments instead global variables
% >>> 2011/10/02 added search frictions with rigid wages using baseline.m
% >>> 2011/10/06 added sector-specific wages
% >>> 2011/10/17 revamped the model. seach + matching + bargaining
% >>> 2011/10/31 Major Revision to the Model - Shimer 2005 unemployment
% >>> 2011/11/21 CHANGED THE UNEMPLOYMENT SETUP - Helpman Itskhoki unempl
% >>> 2011/11/22 Added head-to-head to monopoly switch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% EQUILIBRIUM

myeps     = gvars.myeps;
myfeval    = gvars.myfeval;
myiter      = gvars.myiter;

% iteration
maxit   = 7;

% fsolve options
options = optimset('Display','off','TolFun',myeps,'TolX',myeps,...
    'UseParallel','always','MaxFunEvals',myfeval,'MaxIter',myiter); 

% fsolve call
Xini    = 1/gvars.tau + rand(1);

s1 = warning('off','MATLAB:quadl:ImproperFcnValue');
s2 = warning('off','MATLAB:quadl:MinStepSize');
s3 = warning('off','MATLAB:quadl:MaxFcnCount');
s4 = warning('off','MATLAB:quadv:ImproperFcnValue');
s5 = warning('off','MATLAB:quadv:MinStepSize');
s6 = warning('off','MATLAB:quadv:MaxFcnCount');


tstart  = tic;
fprintf('Solving for the *symmetric* equilibrium \n');

% lb      = myeps;
% ub      = 3;
% [Q, eqmvals, exitflag] = fmincon( ...
%     @(x) ...
%     norm(...
%     eqm(x,gvars) ...
%     ) , ...
%     Xini,[],[],[],[],lb, ub,[] ,options);

[Q, eqmvals, exitflag] = fzero( ...
    @(x) ...
    eqm(x,gvars)  , ...
    Xini,options);


tcomp = toc(tstart);
fprintf('The computation took %9.2f seconds \n', tcomp);

% output
if (exitflag > 0)
    fprintf('fsolve stopped normally \n');
    
    cH_max = cutoffHM(Q,Q,gvars);
    
elseif (gvars.iter <= maxit)
    fprintf('Restarting as No solution was found :( \n');
    gvars_inc = gvars;
    gvars_inc.iter = gvars.iter + 1;
    [Q, cH_max] = h2hlewis(gvars_inc);
else
    fprintf('Stopped. No solution was found :( \n');
    Q       = NaN;
    cH_max  = NaN;

end

warning(s1);
warning(s2);
warning(s3);
warning(s4);
warning(s5);
warning(s6);
end
